@@ -10,7 +10,7 @@ source("init_unit_test.R")
 
 
 
-# Disable these unit tests due to a bug in
+# Disable these unit tests due to a problem in
 #  covr::package_coverage(type = "tests")"
 # # Error: identical(names(y), names) is not TRUE
 # The error is thrown in the function "merge_coverage" (https://github.com/r-lib/covr/blob/master/R/covr.R)
@@ -18,6 +18,8 @@ source("init_unit_test.R")
 # the order of elements in the files to be changed.
 # Note: I am using skip_if_not instead of skip_if to support old testthat versions (e. g. 1.0.2)
 skip_if_not(("covr" %in% loadedNamespaces()) == FALSE, "This unit test is skipped during code coverage profiling with 'covr' due to a bug")
+skip_on_travis()  # since I am using travis CI on github to derive the code coverage with covr
+
 # TODO Open an issue at https://github.com/r-lib/covr and propose ordering the file contents before checking identify:
 #      names[order(names)] == names(y)[order(names(y))]
 
@@ -98,4 +100,3 @@ test_that("existing options are left untouched when package is loaded", {
   expect_true(getOption("tryCatchLog.silent.messages"))
 
 })
-
