@@ -33,15 +33,17 @@ test_that("internal package state is initialized", {
 
   expected_Newline_value <- "test_result"
 
-  with_mock(
-    `tryCatchLog:::determine.platform.NewLine` = function() return(expected_Newline_value),
-    `tryCatchLog:::is.package.available` = function(pkg.name) return(FALSE),
-    expect_message({
-                     tryCatchLog:::.onLoad(".", "tryCatchLog")
-                     tryCatchLog:::.onAttach(".", "tryCatchLog")
-                   },
-                   "futile.logger not found. Using tryCatchLog-internal functions for logging",
-                   info = "with no installed logging package the package-internal logging functions must be used")
+  with_mocked_bindings(
+    code = {
+      expect_message({
+        tryCatchLog:::.onLoad(".", "tryCatchLog")
+        tryCatchLog:::.onAttach(".", "tryCatchLog")
+      },
+      "Using tryCatchLog for logging",
+      info = "with no installed logging package the package-internal logging functions of tryCatchLog must be used")
+    }
+    , determine.platform.NewLine = function() return(expected_Newline_value)
+    , is.package.available       = function(pkg.name) return(FALSE)
   )
 
 
@@ -69,14 +71,47 @@ test_that("futile.logger is used if it is installed", {
 
   skip_if_not_installed("futile.logger")
 
-#  with_mock(
-#    `tryCatchLog:::is.package.available` = function(pkg.name) return(TRUE),
-    # expect_silent(tryCatchLog:::.onAttach(".", "tryCatchLog"))
-    expect_message(tryCatchLog:::.onAttach(".", "tryCatchLog"), "Using futile.logger for logging")
-#  )
+  with_mocked_bindings(
+    code = {
+      options(tryCatchLog.preferred.logging.package = NULL)  # to iterate over all supported packages and check which one is available
+      tryCatchLog:::.onLoad(".", "tryCatchLog")
+      expect_message(tryCatchLog:::.onAttach(".", "tryCatchLog"), "Using futile.logger for logging")
+    }
+    , is.package.available = function(pkg.name) return(pkg.name == "futile.logger")
+  )
 
 })
 
+test_that("lgr is used if it is installed", {
+
+  skip_if_not_installed("lgr")
+
+  with_mocked_bindings(
+    code = {
+      options(tryCatchLog.preferred.logging.package = NULL)  # to iterate over all supported packages and check which one is available
+      tryCatchLog:::.onLoad(".", "tryCatchLog")
+      expect_message(tryCatchLog:::.onAttach(".", "tryCatchLog"), "Using lgr for logging")
+    }
+    , is.package.available = function(pkg.name) return(pkg.name == "lgr")
+    # . env = "tryCatchLog"
+  )
+
+})
+
+
+test_that("internal logging functions are used", {
+
+  with_mocked_bindings(
+    code = {
+      options(tryCatchLog.preferred.logging.package = NULL)  # to iterate over all supported packages and check which one is available
+      tryCatchLog:::.onLoad(".", "tryCatchLog")
+      expect_message(tryCatchLog:::.onAttach(".", "tryCatchLog"), "Using tryCatchLog for logging")
+      # . env = "tryCatchLog"
+    }
+    , is.package.available = function(pkg.name) return(FALSE),
+  )
+
+})
 
 
 test_that("non-existing options are initialized when package is loaded", {
